@@ -1,6 +1,7 @@
 package instance
 
 import (
+	"fmt"
 	"testing"
 
 	"github.com/alecthomas/assert"
@@ -22,11 +23,12 @@ func Test_CreateServer(t *testing.T) {
 	t.Run("Simple", func(t *testing.T) {
 		t.Run("Default", core.Test(&core.TestConfig{
 			Commands: GetCommands(),
-			Cmd:      "scw instance server create image=ubuntu_bionic stopped=true",
+			Cmd:      "scw instance server create image=ubuntu_jammy stopped=true",
 			Check: core.TestCheckCombine(
 				core.TestCheckGolden(),
 				func(t *testing.T, ctx *core.CheckFuncCtx) {
-					assert.Equal(t, "Ubuntu 18.04 Bionic Beaver", ctx.Result.(*instance.Server).Image.Name)
+					assert.NotNil(t, ctx.Result)
+					assert.Equal(t, "Ubuntu 22.04 Jammy Jellyfish", ctx.Result.(*instance.Server).Image.Name)
 				},
 				core.TestCheckExitCode(0),
 			),
@@ -38,6 +40,7 @@ func Test_CreateServer(t *testing.T) {
 			Cmd:      "scw instance server create type=GP1-XS image=ubuntu_bionic stopped=true",
 			Check: core.TestCheckCombine(
 				func(t *testing.T, ctx *core.CheckFuncCtx) {
+					assert.NotNil(t, ctx.Result)
 					assert.Equal(t, "GP1-XS", ctx.Result.(*instance.Server).CommercialType)
 				},
 				core.TestCheckExitCode(0),
@@ -50,6 +53,7 @@ func Test_CreateServer(t *testing.T) {
 			Cmd:      "scw instance server create image=ubuntu_bionic name=yo stopped=true",
 			Check: core.TestCheckCombine(
 				func(t *testing.T, ctx *core.CheckFuncCtx) {
+					assert.NotNil(t, ctx.Result)
 					assert.Equal(t, "yo", ctx.Result.(*instance.Server).Name)
 				},
 				core.TestCheckExitCode(0),
@@ -62,6 +66,7 @@ func Test_CreateServer(t *testing.T) {
 			Cmd:      "scw instance server create image=ubuntu_bionic -w",
 			Check: core.TestCheckCombine(
 				func(t *testing.T, ctx *core.CheckFuncCtx) {
+					assert.NotNil(t, ctx.Result)
 					assert.Equal(t, instance.ServerStateRunning, ctx.Result.(*instance.Server).State)
 				},
 				core.TestCheckExitCode(0),
@@ -74,6 +79,7 @@ func Test_CreateServer(t *testing.T) {
 			Cmd:      "scw instance server create image=ubuntu_bionic bootscript-id=eb760e3c-30d8-49a3-b3ad-ad10c3aa440b stopped=true",
 			Check: core.TestCheckCombine(
 				func(t *testing.T, ctx *core.CheckFuncCtx) {
+					assert.NotNil(t, ctx.Result)
 					//nolint: staticcheck // Bootscript is deprecated
 					assert.Equal(t, "eb760e3c-30d8-49a3-b3ad-ad10c3aa440b", ctx.Result.(*instance.Server).Bootscript.ID)
 					assert.Equal(t, instance.BootTypeBootscript, ctx.Result.(*instance.Server).BootType)
@@ -88,6 +94,7 @@ func Test_CreateServer(t *testing.T) {
 			Cmd:      "scw instance server create image=f974feac-abae-4365-b988-8ec7d1cec10d stopped=true",
 			Check: core.TestCheckCombine(
 				func(t *testing.T, ctx *core.CheckFuncCtx) {
+					assert.NotNil(t, ctx.Result)
 					assert.Equal(t, "Ubuntu Bionic Beaver", ctx.Result.(*instance.Server).Image.Name)
 				},
 				core.TestCheckExitCode(0),
@@ -100,6 +107,7 @@ func Test_CreateServer(t *testing.T) {
 			Cmd:      "scw instance server create image=ubuntu_bionic tags.0=prod tags.1=blue stopped=true",
 			Check: core.TestCheckCombine(
 				func(t *testing.T, ctx *core.CheckFuncCtx) {
+					assert.NotNil(t, ctx.Result)
 					assert.Equal(t, "prod", ctx.Result.(*instance.Server).Tags[0])
 					assert.Equal(t, "blue", ctx.Result.(*instance.Server).Tags[1])
 				},
@@ -118,6 +126,7 @@ func Test_CreateServer(t *testing.T) {
 			Cmd:      "scw instance server create image=ubuntu_bionic root-volume=local:20GB stopped=true",
 			Check: core.TestCheckCombine(
 				func(t *testing.T, ctx *core.CheckFuncCtx) {
+					assert.NotNil(t, ctx.Result)
 					assert.Equal(t, 20*scw.GB, ctx.Result.(*instance.Server).Volumes["0"].Size)
 				},
 				core.TestCheckExitCode(0),
@@ -135,6 +144,7 @@ func Test_CreateServer(t *testing.T) {
 			Check: core.TestCheckCombine(
 				core.TestCheckExitCode(0),
 				func(t *testing.T, ctx *core.CheckFuncCtx) {
+					assert.NotNil(t, ctx.Result)
 					assert.Equal(t, 20*scw.GB, ctx.Result.(*instance.Server).Volumes["0"].Size)
 				},
 			),
@@ -150,6 +160,7 @@ func Test_CreateServer(t *testing.T) {
 			Cmd:      "scw instance server create image=ubuntu_bionic root-volume=local:10GB additional-volumes.0=l:10G stopped=true",
 			Check: core.TestCheckCombine(
 				func(t *testing.T, ctx *core.CheckFuncCtx) {
+					assert.NotNil(t, ctx.Result)
 					assert.Equal(t, 10*scw.GB, ctx.Result.(*instance.Server).Volumes["0"].Size)
 					assert.Equal(t, 10*scw.GB, ctx.Result.(*instance.Server).Volumes["1"].Size)
 				},
@@ -168,6 +179,7 @@ func Test_CreateServer(t *testing.T) {
 			Check: core.TestCheckCombine(
 				core.TestCheckExitCode(0),
 				func(t *testing.T, ctx *core.CheckFuncCtx) {
+					assert.NotNil(t, ctx.Result)
 					assert.Equal(t, 20*scw.GB, ctx.Result.(*instance.Server).Volumes["0"].Size)
 					assert.Equal(t, 20*scw.GB, ctx.Result.(*instance.Server).Volumes["1"].Size)
 				},
@@ -184,6 +196,7 @@ func Test_CreateServer(t *testing.T) {
 			Cmd:      "scw instance server create image=ubuntu_bionic additional-volumes.0=b:1G additional-volumes.1=b:5G additional-volumes.2=b:10G stopped=true",
 			Check: core.TestCheckCombine(
 				func(t *testing.T, ctx *core.CheckFuncCtx) {
+					assert.NotNil(t, ctx.Result)
 					assert.Equal(t, 1*scw.GB, ctx.Result.(*instance.Server).Volumes["1"].Size)
 					assert.Equal(t, 5*scw.GB, ctx.Result.(*instance.Server).Volumes["2"].Size)
 					assert.Equal(t, 10*scw.GB, ctx.Result.(*instance.Server).Volumes["3"].Size)
@@ -202,6 +215,7 @@ func Test_CreateServer(t *testing.T) {
 			Cmd:      "scw instance server create image=ubuntu_bionic ip=new stopped=true",
 			Check: core.TestCheckCombine(
 				func(t *testing.T, ctx *core.CheckFuncCtx) {
+					assert.NotNil(t, ctx.Result)
 					assert.NotEmpty(t, ctx.Result.(*instance.Server).PublicIP.Address)
 					assert.Equal(t, false, ctx.Result.(*instance.Server).PublicIP.Dynamic)
 				},
@@ -216,6 +230,7 @@ func Test_CreateServer(t *testing.T) {
 			Check: core.TestCheckCombine(
 				func(t *testing.T, ctx *core.CheckFuncCtx) {
 					assert.NoError(t, ctx.Err)
+					assert.NotNil(t, ctx.Result)
 					assert.NotEmpty(t, ctx.Result.(*instance.Server).PublicIP.Address)
 					assert.Equal(t, true, ctx.Result.(*instance.Server).DynamicIPRequired)
 				},
@@ -230,6 +245,7 @@ func Test_CreateServer(t *testing.T) {
 			Cmd:        "scw instance server create image=ubuntu_bionic ip={{ .IP.Address }} stopped=true",
 			Check: core.TestCheckCombine(
 				func(t *testing.T, ctx *core.CheckFuncCtx) {
+					assert.NotNil(t, ctx.Result)
 					assert.NotEmpty(t, ctx.Result.(*instance.Server).PublicIP.Address)
 					assert.Equal(t, false, ctx.Result.(*instance.Server).PublicIP.Dynamic)
 				},
@@ -244,6 +260,7 @@ func Test_CreateServer(t *testing.T) {
 			Cmd:        "scw instance server create image=ubuntu_bionic ip={{ .IP.ID }} stopped=true",
 			Check: core.TestCheckCombine(
 				func(t *testing.T, ctx *core.CheckFuncCtx) {
+					assert.NotNil(t, ctx.Result)
 					assert.NotEmpty(t, ctx.Result.(*instance.Server).PublicIP.Address)
 					assert.Equal(t, false, ctx.Result.(*instance.Server).PublicIP.Dynamic)
 				},
@@ -257,6 +274,7 @@ func Test_CreateServer(t *testing.T) {
 			Cmd:      "scw instance server create image=ubuntu_bionic ipv6=true -w", // IPv6 is created at runtime
 			Check: core.TestCheckCombine(
 				func(t *testing.T, ctx *core.CheckFuncCtx) {
+					assert.NotNil(t, ctx.Result)
 					assert.NotEmpty(t, ctx.Result.(*instance.Server).IPv6.Address)
 				},
 				core.TestCheckExitCode(0),
@@ -298,7 +316,7 @@ func Test_CreateServerErrors(t *testing.T) {
 	////
 	t.Run("Error: invalid instance type", core.Test(&core.TestConfig{
 		Commands: GetCommands(),
-		Cmd:      "scw instance server create type=MACBOOK1-S image=ubuntu_bionic",
+		Cmd:      "scw instance server create type=MACBOOK1-S image=ubuntu_jammy",
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
 			core.TestCheckExitCode(1),
@@ -311,7 +329,7 @@ func Test_CreateServerErrors(t *testing.T) {
 	////
 	t.Run("Error: invalid total local volumes size: too low 1", core.Test(&core.TestConfig{
 		Commands: GetCommands(),
-		Cmd:      "scw instance server create image=ubuntu_bionic root-volume=l:5GB",
+		Cmd:      "scw instance server create image=ubuntu_jammy root-volume=l:5GB",
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
 			core.TestCheckExitCode(1),
@@ -321,7 +339,7 @@ func Test_CreateServerErrors(t *testing.T) {
 
 	t.Run("Error: invalid total local volumes size: too low 2", core.Test(&core.TestConfig{
 		Commands: GetCommands(),
-		Cmd:      "scw instance server create image=ubuntu_bionic root-volume=l:5GB additional-volumes.0=block:10GB",
+		Cmd:      "scw instance server create image=ubuntu_jammy root-volume=l:5GB additional-volumes.0=block:10GB",
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
 			core.TestCheckExitCode(1),
@@ -332,7 +350,7 @@ func Test_CreateServerErrors(t *testing.T) {
 	t.Run("Error: invalid total local volumes size: too low 3", core.Test(&core.TestConfig{
 		Commands:   GetCommands(),
 		BeforeFunc: createVolume("Volume", 5, instance.VolumeVolumeTypeLSSD),
-		Cmd:        "scw instance server create image=ubuntu_bionic root-volume={{ .Volume.ID }}",
+		Cmd:        "scw instance server create image=ubuntu_jammy root-volume={{ .Volume.ID }}",
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
 			core.TestCheckExitCode(1),
@@ -342,7 +360,7 @@ func Test_CreateServerErrors(t *testing.T) {
 
 	t.Run("Error: invalid total local volumes size: too high 1", core.Test(&core.TestConfig{
 		Commands: GetCommands(),
-		Cmd:      "scw instance server create image=ubuntu_bionic root-volume=local:10GB additional-volumes.0=local:20GB",
+		Cmd:      "scw instance server create image=ubuntu_jammy root-volume=local:10GB additional-volumes.0=local:20GB",
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
 			core.TestCheckExitCode(1),
@@ -352,7 +370,7 @@ func Test_CreateServerErrors(t *testing.T) {
 
 	t.Run("Error: invalid total local volumes size: too high 2", core.Test(&core.TestConfig{
 		Commands: GetCommands(),
-		Cmd:      "scw instance server create image=ubuntu_bionic additional-volumes.0=local:20GB",
+		Cmd:      "scw instance server create image=ubuntu_jammy additional-volumes.0=local:20GB",
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
 			core.TestCheckExitCode(1),
@@ -363,7 +381,7 @@ func Test_CreateServerErrors(t *testing.T) {
 	t.Run("Error: invalid total local volumes size: too high 3", core.Test(&core.TestConfig{
 		Commands:   GetCommands(),
 		BeforeFunc: createVolume("Volume", 20, instance.VolumeVolumeTypeLSSD),
-		Cmd:        "scw instance server create image=ubuntu_bionic root-volume={{ .Volume.ID }} additional-volumes.0=local:10GB",
+		Cmd:        "scw instance server create image=ubuntu_jammy root-volume={{ .Volume.ID }} additional-volumes.0=local:10GB",
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
 			core.TestCheckExitCode(1),
@@ -374,7 +392,7 @@ func Test_CreateServerErrors(t *testing.T) {
 
 	t.Run("Error: invalid root volume size", core.Test(&core.TestConfig{
 		Commands: GetCommands(),
-		Cmd:      "scw instance server create image=ubuntu_bionic root-volume=local:2GB additional-volumes.0=local:18GB",
+		Cmd:      "scw instance server create image=ubuntu_jammy root-volume=local:2GB additional-volumes.0=local:18GB",
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
 			core.TestCheckExitCode(1),
@@ -385,7 +403,7 @@ func Test_CreateServerErrors(t *testing.T) {
 	t.Run("Error: disallow existing root volume ID", core.Test(&core.TestConfig{
 		Commands:   GetCommands(),
 		BeforeFunc: createVolume("Volume", 20, instance.VolumeVolumeTypeLSSD),
-		Cmd:        "scw instance server create image=ubuntu_bionic root-volume={{ .Volume.ID }}",
+		Cmd:        "scw instance server create image=ubuntu_jammy root-volume={{ .Volume.ID }}",
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
 			core.TestCheckExitCode(1),
@@ -396,7 +414,7 @@ func Test_CreateServerErrors(t *testing.T) {
 
 	t.Run("Error: invalid root volume ID", core.Test(&core.TestConfig{
 		Commands: GetCommands(),
-		Cmd:      "scw instance server create image=ubuntu_bionic root-volume=29da9ad9-e759-4a56-82c8-f0607f93055c",
+		Cmd:      "scw instance server create image=ubuntu_jammy root-volume=29da9ad9-e759-4a56-82c8-f0607f93055c",
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
 			core.TestCheckExitCode(1),
@@ -406,8 +424,8 @@ func Test_CreateServerErrors(t *testing.T) {
 
 	t.Run("Error: already attached additional volume ID", core.Test(&core.TestConfig{
 		Commands:   GetCommands(),
-		BeforeFunc: core.ExecStoreBeforeCmd("Server", "scw instance server create name=cli-test image=ubuntu_bionic root-volume=l:10G additional-volumes.0=l:10G stopped=true"),
-		Cmd:        `scw instance server create image=ubuntu_bionic root-volume=l:10G additional-volumes.0={{ (index .Server.Volumes "1").ID }} stopped=true`,
+		BeforeFunc: core.ExecStoreBeforeCmd("Server", "scw instance server create name=cli-test image=ubuntu_jammy root-volume=l:10G additional-volumes.0=l:10G stopped=true"),
+		Cmd:        `scw instance server create image=ubuntu_jammy root-volume=l:10G additional-volumes.0={{ (index .Server.Volumes "1").ID }} stopped=true`,
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
 			core.TestCheckExitCode(1),
@@ -418,7 +436,7 @@ func Test_CreateServerErrors(t *testing.T) {
 
 	t.Run("Error: invalid root volume format", core.Test(&core.TestConfig{
 		Commands: GetCommands(),
-		Cmd:      "scw instance server create image=ubuntu_bionic root-volume=20GB",
+		Cmd:      "scw instance server create image=ubuntu_jammy root-volume=20GB",
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
 			core.TestCheckExitCode(1),
@@ -428,7 +446,7 @@ func Test_CreateServerErrors(t *testing.T) {
 
 	t.Run("Error: invalid root volume snapshot ID", core.Test(&core.TestConfig{
 		Commands: GetCommands(),
-		Cmd:      "scw instance server create image=ubuntu_bionic root-volume=local:29da9ad9-e759-4a56-82c8-f0607f93055c",
+		Cmd:      "scw instance server create image=ubuntu_jammy root-volume=local:29da9ad9-e759-4a56-82c8-f0607f93055c",
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
 			core.TestCheckExitCode(1),
@@ -438,7 +456,7 @@ func Test_CreateServerErrors(t *testing.T) {
 
 	t.Run("Error: invalid additional volume snapshot ID", core.Test(&core.TestConfig{
 		Commands: GetCommands(),
-		Cmd:      "scw instance server create image=ubuntu_bionic additional-volumes.0=block:29da9ad9-e759-4a56-82c8-f0607f93055c",
+		Cmd:      "scw instance server create image=ubuntu_jammy additional-volumes.0=block:29da9ad9-e759-4a56-82c8-f0607f93055c",
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
 			core.TestCheckExitCode(1),
@@ -451,7 +469,7 @@ func Test_CreateServerErrors(t *testing.T) {
 	////
 	t.Run("Error: not found ip ID", core.Test(&core.TestConfig{
 		Commands: GetCommands(),
-		Cmd:      "scw instance server create image=ubuntu_bionic ip=23165951-13fd-4a3b-84ed-22c2e96658f2",
+		Cmd:      "scw instance server create image=ubuntu_jammy ip=23165951-13fd-4a3b-84ed-22c2e96658f2",
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
 			core.TestCheckExitCode(1),
@@ -460,7 +478,7 @@ func Test_CreateServerErrors(t *testing.T) {
 
 	t.Run("Error: forbidden IP", core.Test(&core.TestConfig{
 		Commands: GetCommands(),
-		Cmd:      "scw instance server create image=ubuntu_bionic ip=51.15.242.82",
+		Cmd:      "scw instance server create image=ubuntu_jammy ip=51.15.242.82",
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
 			core.TestCheckExitCode(1),
@@ -469,7 +487,7 @@ func Test_CreateServerErrors(t *testing.T) {
 
 	t.Run("Error: invalid ip", core.Test(&core.TestConfig{
 		Commands: GetCommands(),
-		Cmd:      "scw instance server create image=ubuntu_bionic ip=yo",
+		Cmd:      "scw instance server create image=ubuntu_jammy ip=yo",
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
 			core.TestCheckExitCode(1),
@@ -485,3 +503,30 @@ func Test_CreateServerErrors(t *testing.T) {
 		),
 	}))
 }
+
+func Test_CreateServerScratchStorage(t *testing.T) {
+	t.Run("Default scratch storage", core.Test(&core.TestConfig{
+		Commands: GetCommands(),
+		Cmd:      "scw instance server create type=H100-1-80G image=ubuntu_jammy_gpu_os_12 zone=fr-par-2",
+		Check: core.TestCheckCombine(
+			core.TestCheckGolden(),
+			func(t *testing.T, ctx *core.CheckFuncCtx) {
+				fmt.Println(ctx.LogBuffer)
+			},
+			core.TestCheckExitCode(0),
+			func(t *testing.T, ctx *core.CheckFuncCtx) {
+				server, isServer := ctx.Result.(*instance.Server)
+				if !isServer {
+					t.Fatalf("Result is not a server")
+				}
+				additionalVolume, exist := server.Volumes["1"]
+				if !exist {
+					t.Fatalf("Expected an additional scratch volume, found none")
+				}
+				assert.Equal(t, additionalVolume.VolumeType, instance.VolumeServerVolumeTypeScratch)
+			},
+		),
+		AfterFunc:       core.ExecAfterCmd("scw instance server delete {{ .CmdResult.ID }} zone=fr-par-2 with-volumes=all with-ip=true force-shutdown=true"),
+		DisableParallel: true,
+	}))
+}
