@@ -38,6 +38,8 @@ func GetCommands() *core.Commands {
 	cmds.MustFind("rdb", "instance", "clone").Override(instanceCloneBuilder)
 	cmds.MustFind("rdb", "instance", "upgrade").Override(instanceUpgradeBuilder)
 	cmds.MustFind("rdb", "instance", "update").Override(instanceUpdateBuilder)
+	cmds.MustFind("rdb", "instance", "get").Override(instanceGetBuilder)
+	cmds.MustFind("rdb", "instance", "delete").Override(instanceDeleteBuilder)
 
 	cmds.MustFind("rdb", "engine", "list").Override(engineListBuilder)
 
