@@ -6,7 +6,16 @@ import (
 
 	"github.com/alecthomas/assert"
 	"github.com/scaleway/scaleway-cli/v2/internal/core"
+	"github.com/scaleway/scaleway-cli/v2/internal/namespaces/vpc/v2"
+	"github.com/scaleway/scaleway-sdk-go/api/ipam/v1"
 	"github.com/scaleway/scaleway-sdk-go/api/rdb/v1"
+	"github.com/scaleway/scaleway-sdk-go/scw"
+)
+
+const (
+	publicEndpoint        = "public"
+	privateEndpointIpam   = "private IPAM"
+	privateEndpointStatic = "private static"
 )
 
 func Test_ListInstance(t *testing.T) {
@@ -31,9 +40,14 @@ func Test_CloneInstance(t *testing.T) {
 
 func Test_CreateInstance(t *testing.T) {
 	t.Run("Simple", core.Test(&core.TestConfig{
-		Commands:  GetCommands(),
-		Cmd:       fmt.Sprintf("scw rdb instance create node-type=DB-DEV-S is-ha-cluster=false name=%s engine=%s user-name=%s password=%s --wait", name, engine, user, password),
-		Check:     core.TestCheckGolden(),
+		Commands: GetCommands(),
+		Cmd:      fmt.Sprintf("scw rdb instance create node-type=DB-DEV-S is-ha-cluster=false name=%s engine=%s user-name=%s password=%s --wait", name, engine, user, password),
+		Check: core.TestCheckCombine(
+			core.TestCheckGolden(),
+			func(t *testing.T, ctx *core.CheckFuncCtx) {
+				checkEndpoints(ctx, t, []string{publicEndpoint})
+			},
+		),
 		AfterFunc: core.ExecAfterCmd("scw rdb instance delete {{ .CmdResult.ID }}"),
 	}))
 
@@ -41,9 +55,57 @@ func Test_CreateInstance(t *testing.T) {
 		Commands: GetCommands(),
 		Cmd:      fmt.Sprintf("scw rdb instance create node-type=DB-DEV-S is-ha-cluster=false name=%s engine=%s user-name=%s generate-password=true --wait", name, engine, user),
 		// do not check the golden as the password generated locally and on CI will necessarily be different
-		Check:     core.TestCheckExitCode(0),
+		Check: core.TestCheckCombine(
+			core.TestCheckExitCode(0),
+			func(t *testing.T, ctx *core.CheckFuncCtx) {
+				checkEndpoints(ctx, t, []string{publicEndpoint})
+			},
+		),
 		AfterFunc: core.ExecAfterCmd("scw rdb instance delete {{ .CmdResult.ID }}"),
 	}))
+
+	cmds := GetCommands()
+	cmds.Merge(vpc.GetCommands())
+
+	t.Run("With static private endpoint", core.Test(&core.TestConfig{
+		Commands: cmds,
+		BeforeFunc: core.BeforeFuncCombine(
+			core.ExecStoreBeforeCmd("PrivateNetwork", "scw vpc private-network create"),
+		),
+		Cmd: fmt.Sprintf("scw rdb instance create node-type=DB-DEV-S is-ha-cluster=false name=%s engine=%s "+
+			"user-name=%s password=%s init-endpoints.0.private-network.private-network-id={{ .PrivateNetwork.ID }} "+
+			"init-endpoints.0.private-network.service-ip=172.16.4.1/22 --wait", name, engine, user, password),
+		Check: core.TestCheckCombine(
+			core.TestCheckGolden(),
+			func(t *testing.T, ctx *core.CheckFuncCtx) {
+				checkEndpoints(ctx, t, []string{publicEndpoint, privateEndpointStatic})
+			},
+		),
+		AfterFunc: core.AfterFuncCombine(
+			core.ExecAfterCmd("scw rdb instance delete {{ .CmdResult.ID }} --wait"),
+			deletePrivateNetwork("PrivateNetwork"),
+		),
+	}))
+
+	t.Run("With IPAM private endpoint", core.Test(&core.TestConfig{
+		Commands: cmds,
+		BeforeFunc: core.BeforeFuncCombine(
+			core.ExecStoreBeforeCmd("PrivateNetwork", "scw vpc private-network create"),
+		),
+		Cmd: fmt.Sprintf("scw rdb instance create node-type=DB-DEV-S is-ha-cluster=false name=%s engine=%s "+
+			"user-name=%s password=%s init-endpoints.0.private-network.private-network-id={{ .PrivateNetwork.ID }} "+
+			"init-endpoints.0.private-network.enable-ipam=true --wait", name, engine, user, password),
+		Check: core.TestCheckCombine(
+			core.TestCheckGolden(),
+			func(t *testing.T, ctx *core.CheckFuncCtx) {
+				checkEndpoints(ctx, t, []string{publicEndpoint, privateEndpointIpam})
+			},
+		),
+		AfterFunc: core.AfterFuncCombine(
+			core.ExecAfterCmd("scw rdb instance delete {{ .CmdResult.ID }} --wait"),
+			deletePrivateNetwork("PrivateNetwork"),
+		),
+	}))
 }
 
 func Test_GetInstance(t *testing.T) {
@@ -101,8 +163,8 @@ func Test_UpdateInstance(t *testing.T) {
 		Cmd:        "scw rdb instance update {{ .Instance.ID }} settings.0.name=timezone settings.0.value=UTC --wait",
 		Check: core.TestCheckCombine(
 			func(t *testing.T, ctx *core.CheckFuncCtx) {
-				assert.Equal(t, "timezone", ctx.Result.(*rdb.Instance).Settings[6].Name)
-				assert.Equal(t, "UTC", ctx.Result.(*rdb.Instance).Settings[6].Value)
+				assert.Equal(t, "timezone", ctx.Result.(*rdb.Instance).Settings[5].Name)
+				assert.Equal(t, "UTC", ctx.Result.(*rdb.Instance).Settings[5].Value)
 			},
 			core.TestCheckGolden(),
 			core.TestCheckExitCode(0),
@@ -116,8 +178,8 @@ func Test_UpdateInstance(t *testing.T) {
 		Cmd:        "scw rdb instance update {{ .Instance.ID }} settings.0.name=work_mem settings.0.value=8 --wait",
 		Check: core.TestCheckCombine(
 			func(t *testing.T, ctx *core.CheckFuncCtx) {
-				assert.Equal(t, "work_mem", ctx.Result.(*rdb.Instance).Settings[0].Name)
-				assert.Equal(t, "8", ctx.Result.(*rdb.Instance).Settings[0].Value)
+				assert.Equal(t, "work_mem", ctx.Result.(*rdb.Instance).Settings[5].Name)
+				assert.Equal(t, "8", ctx.Result.(*rdb.Instance).Settings[5].Value)
 			},
 			core.TestCheckGolden(),
 			core.TestCheckExitCode(0),
@@ -141,14 +203,14 @@ func Test_UpdateInstance(t *testing.T) {
 			" name=foo2 --wait",
 		Check: core.TestCheckCombine(
 			func(t *testing.T, ctx *core.CheckFuncCtx) {
-				assert.Equal(t, "work_mem", ctx.Result.(*rdb.Instance).Settings[0].Name)
-				assert.Equal(t, "16", ctx.Result.(*rdb.Instance).Settings[0].Value)
-				assert.Equal(t, "max_connections", ctx.Result.(*rdb.Instance).Settings[1].Name)
-				assert.Equal(t, "150", ctx.Result.(*rdb.Instance).Settings[1].Value)
-				assert.Equal(t, "effective_cache_size", ctx.Result.(*rdb.Instance).Settings[2].Name)
-				assert.Equal(t, "1200", ctx.Result.(*rdb.Instance).Settings[2].Value)
-				assert.Equal(t, "maintenance_work_mem", ctx.Result.(*rdb.Instance).Settings[3].Name)
-				assert.Equal(t, "200", ctx.Result.(*rdb.Instance).Settings[3].Value)
+				assert.Equal(t, "effective_cache_size", ctx.Result.(*rdb.Instance).Settings[0].Name)
+				assert.Equal(t, "1200", ctx.Result.(*rdb.Instance).Settings[0].Value)
+				assert.Equal(t, "maintenance_work_mem", ctx.Result.(*rdb.Instance).Settings[1].Name)
+				assert.Equal(t, "200", ctx.Result.(*rdb.Instance).Settings[1].Value)
+				assert.Equal(t, "max_connections", ctx.Result.(*rdb.Instance).Settings[2].Name)
+				assert.Equal(t, "150", ctx.Result.(*rdb.Instance).Settings[2].Value)
+				assert.Equal(t, "work_mem", ctx.Result.(*rdb.Instance).Settings[5].Name)
+				assert.Equal(t, "16", ctx.Result.(*rdb.Instance).Settings[5].Value)
 				assert.Equal(t, "foo2", ctx.Result.(*rdb.Instance).Name)
 			},
 			core.TestCheckGolden(),
@@ -204,3 +266,53 @@ func Test_Connect(t *testing.T) {
 		AfterFunc:    deleteInstance(),
 	}))
 }
+
+func deletePrivateNetwork(metaName string) core.AfterFunc {
+	return core.ExecAfterCmd(fmt.Sprintf("scw vpc private-network delete {{ .%s.ID }}", metaName))
+}
+
+func checkEndpoints(ctx *core.CheckFuncCtx, t *testing.T, expected []string) {
+	instance := ctx.Result.(createInstanceResult).Instance
+	ipamAPI := ipam.NewAPI(ctx.Client)
+	var foundEndpoints = map[string]bool{}
+
+	for _, endpoint := range instance.Endpoints {
+		if endpoint.LoadBalancer != nil {
+			foundEndpoints[publicEndpoint] = true
+		}
+		if endpoint.PrivateNetwork != nil {
+			ips, err := ipamAPI.ListIPs(&ipam.ListIPsRequest{
+				Region:       instance.Region,
+				ResourceID:   &instance.ID,
+				ResourceType: "rdb_instance",
+				IsIPv6:       scw.BoolPtr(false),
+			}, scw.WithAllPages())
+			if err != nil {
+				t.Errorf("could not list IPs: %v", err)
+			}
+			switch ips.TotalCount {
+			case 1:
+				foundEndpoints[privateEndpointIpam] = true
+			case 0:
+				foundEndpoints[privateEndpointStatic] = true
+			default:
+				t.Errorf("expected no more than 1 IP for instance, got %d", ips.TotalCount)
+			}
+		}
+	}
+
+	// Check that every expected endpoint got found
+	for _, e := range expected {
+		_, ok := foundEndpoints[e]
+		if !ok {
+			t.Errorf("expected a %s endpoint but got none", e)
+		}
+		delete(foundEndpoints, e)
+	}
+	// Check that no unexpected endpoint was found
+	if len(foundEndpoints) > 0 {
+		for e := range foundEndpoints {
+			t.Errorf("found a %s endpoint when none was expected", e)
+		}
+	}
+}
